coverage: 95% empirical coverage probability for a pqrBayes object

View source: R/coverage.R

coverageR Documentation

95% empirical coverage probability for a pqrBayes object

Description

Calculate 95% empirical coverage probabilities for regression coefficients under a sparse linear model (with a continuous response), binary LASSO, group LASSO and VC models, respectively.

Usage

coverage(object,coefficient,u.grid=NULL,model="linear")

Arguments

object

the pqrBayes object.

coefficient

the vector of true regression coefficients under the sparse linear model (with a continuous response), binary LASSO, group LASSO, or the matrix of true varying coefficients evaluated on the grid points under a varying coefficient model.

u.grid

the vector of grid points under a varying coefficient model. When assessing empirical coverage probabilities under a sparse linear model, binary LASSO or group LASSO, u.grid = NULL.

model

the model to be fitted. Users can also choose "linear" for a sparse linear model (with a continuous response), "binary" for binary LASSO, "group" for group LASSO, and "VC" for a sparse varying coefficient model.

Value

c

See Also

pqrBayes

Examples

## The Bayesian regularized quantile regression model
data(data)
data = data$data_linear
g=data$g
y=data$y
e=data$e
coeff = data$coeff
fit1=pqrBayes(g,y,e,d = NULL,quant=0.5,model="linear")
coverage=coverage(fit1,coeff,model="linear")

pqrBayes documentation built on March 15, 2026, 1:07 a.m.